Webmention Rocks!

# Test #3

This post advertises its Webmention endpoint with an HTML `<link>` tag in the document. The URL is relative, so this will also test whether your discovery code properly resolves the relative URL.
Friday April 15, 2016 8:06am -07:00

### Reacji

The emoji below show Reacji responses, created by people posting a comment linking to this post with an `in-reply-to` property, whose text is a single emoji character.

- 🔀 1
  - https://snarfed.org/2016-04-14_webmention-rocks-5

### Likes

The profile icons below are the author photos from people who have posted a "like" post on their site, where their post links to this post with the `like-of` property.

### Reposts

The profile icons below are the author photos from people who have posted a "repost" of this post on their site, where their post links to this post with the `repost-of` property.

### Bookmarks

The profile icons below are the author photos from people who have posted a bookmark of this post on their site, where their post links to this post with the `bookmark-of` property.

### Comments

The comments below are replies to this post, and marked up their link to the post with the `in-reply-to` property.

- Ryan Barrett snarfed.org

  ### Webmention Rocks!

  Monday, April 11, 2016 10:51am -07:00
- Tantek Çelik tantek.com
  @webmentionrocks tests 1-21 passing with @Falcon using @cassisjs and link-rel-parser-php! https://github.com/indieweb/link-rel-parser-php
  Friday, April 15, 2016 4:32am -07:00
- Nicolas Cluzeau mabulledu.net

  ### Webmention test

  Monday, April 11, 2016 11:54pm +00:00
- Ryan Barrett snarfed.org

  ### Webmention Rocks!

  Wednesday, April 13, 2016 11:40am -07:00
- gRegor Morrill gregorlove.com

  Are you lava-ing this as much as I am?

  Monday, April 11, 2016 12:21pm -07:00
- Tantek Çelik tantek.com
  @webmentionrocks passed 8 for 8, using @Falcon and open source link-rel-parser-php: https://github.com/indieweb/link-rel-parser-php
  Monday, April 11, 2016 11:56am -07:00
- Tantek Çelik tantek.com
  @webmentionrocks nice work! Here’s an 8 test multi-reply per https://indiewebcamp.com/multi-reply
  Monday, April 11, 2016 10:13am -07:00

### Mentions

The mentions below linked to this post, but did not include this post's URL as an `in-reply-to` property.

- Aaron Parecki aaronparecki.com

  Here is my test post for webmention.rocks! Posted using p3k, Webmentions sent by Telegraph using the mention-client-php library.

  Test 1, Test 2, Test 3, Test 4, Test 5, Test 6, Test 7, Test 8, Test 9, Test 10, Test 11, Test 12, Test 13, Test 14, Test 15, Test 16, Test 17, Test 18, Test 19, Test 20

  Thursday, April 14, 2016 6:12pm +02:00
- Jeena jeena.net

  ### Note #628

  Thursday, April 14, 2016 7:19pm +00:00
- Kyle Mahan kylewm.com

  ## Trying webmention.rocks from Known

  1 min read

  - Test 1 - HTTP Link header, unquoted rel, relative URL
  - Test 2 - HTTP Link header, unquoted rel, absolute URL
  - Test 3 - HTML <link> tag, relative URL
  - Test 4 - HTML <link> tag, absolute URL
  - Test 5 - HTML <a> tag, relative URL
  - Test 6 - HTML <a> tag, absolute URL
  - Test 7 - HTTP Link header with strange casing
  - Test 8 - HTTP Link header, quoted rel
  Tuesday, April 12, 2016 5:11am +00:00
- Kyle Mahan 2015.kylewm.com

  Webmention.rocks test from Red Wind just out of curiosity :P

  https://webmention.rocks/test/1 https://webmention.rocks/test/2 https://webmention.rocks/test/3 https://webmention.rocks/test/4 https://webmention.rocks/test/5 https://webmention.rocks/test/6 https://webmention.rocks/test/7 https://webmention.rocks/test/8

  Tuesday, April 12, 2016 10:35am -07:00
- No Name
  Comment text not found
  http://mention-tech.appspot.com/testing.html

  The post did not provide a URL, using source instead

- Mike Taylor bear.im

  ### Testing Webmention.rocks

  Sunday, April 10, 2016 10:48pm +00:00